# Generated by roxygen2: do not edit by hand

export(ST_freq_factor)
export(ST_freq_numeric)
export(runStatisticTeach1)
import(DescTools)
import(RColorBrewer)
import(descriptr)
import(dplyr)
import(ggplot2)
import(mixdist)
import(shiny)
import(shinydashboard)
import(tibble)
import(tidyr)
importFrom(DT,datatable)
importFrom(DT,formatRound)
importFrom(DT,formatStyle)
importFrom(DT,renderDT)
importFrom(DT,styleEqual)
importFrom(colourpicker,colourInput)
importFrom(colourpicker,colourWidget)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(magrittr,"%<>%")
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(rlang,enquo)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(shinyBS,bsModal)
importFrom(shinyWidgets,actionBttn)
importFrom(shinyWidgets,animateOptions)
importFrom(shinyWidgets,dropdown)
importFrom(shinyWidgets,pickerInput)
importFrom(shinyWidgets,prettyCheckbox)
importFrom(shinyWidgets,switchInput)
importFrom(shinyjs,disable)
importFrom(shinyjs,enable)
importFrom(shinyjs,useShinyjs)
importFrom(stats,na.omit)
