graphic_summaries <- tabPanel("Graphic summary",
                    div(style="display: inline-block;vertical-align:top;
                        width: 150px;",shinyWidgets::pickerInput(
                          inputId = "SelecQu",
                          label = "Select:",
                          choices = c("",
                                      "Barplot",
                                      "Pie"),
                          options = list(
                            style = "btn-primary")), prettySwitch(
        inputId = "horizontal_plot_qualitative",
        label = "Horizontal", 
        status = "primary",
        slim = TRUE
      )),
                    conditionalPanel( condition = "input.SelecQu == 'Barplot'& input.GrupoQuali == 0",
                      br(),
                      strong(h3("Barplot")),
                      br(),
                      plotOutput("plotQu"),
                      br(),
                      downloadButton("QualitativeBarplotDownloadGrupo", "Download Graph", class = "btn-primary"),
                      br(), br(),
                      shinyWidgets::dropdown(
                        label = "Customize graph",
                        tags$h3("Customize"),
                        div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBarplotQualiNoGrupo",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
                        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("themeQu", " Theme",
                                   choices = names(themesb))),
        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontQu", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("ylabQu",
                      label = "ylab",
                      value = "Write ylab...")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            textInput("xlabQu",
                      label = "xlab",
                      value = "Write xlab...")),
        div(style="display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput("linecolorQu",
                  label = "Color",
                  value = "red")),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("fillQu",
                      label = "Color fill",
                      value = "#0095ff")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "lwdQu",
                        label = "Line width",
                        min = 0.1,
                        max =10 ,
                        value = 1.5)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontqu",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphaQu",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.5)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))
        ),
        conditionalPanel(condition = "input.SelecQu == 'Barplot'& input.GrupoQuali == 1",
          br(),
          helpText("Barplot"),
          br(),
          plotOutput("plotQu2"),
          br(),
          downloadButton("QualitativeBarplotDownloadNoGrupo", "Download Graph", class = "btn-primary"),
          br(), br(),
          shinyWidgets::dropdown(
            label = "Customize graph",tags$h3("Customize"), div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetBarplotQualiGrupo",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
            div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("themeQu2", " Theme",
                                   choices = names(themesb))),
        div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontQu2", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("ylabQu2",
                      label = "ylab",
                      value = "Write ylab...")),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            textInput("xlabQu2",
                      label = "xlab",
                      value = "Write xlab...")),
        div(style="display: inline-block;
        vertical-align:top; width: 150px;",
        colourInput("linecolorQu2",
                  label = "Color line",
                  value = "red")),
        div(
          style="display: inline-block;vertical-align:top; width: 150px;",
          selectInput("paletasQu2",
                      "Palletes",
                      choices = paletas)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "lwdQu2",
                        label = "Line width",
                        min = 0.1,
                        max =10 ,
                        value = 1.5)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontqu2",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphaQu2",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.7)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "angleQu",
                        label = "angle",
                        min = 0,
                        max =90 ,value = 1)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))
        ),
        conditionalPanel( condition = "input.SelecQu == 'Pie'",
          br(),
          strong(h3("Pie")),
          conditionalPanel( condition = "input.GrupoQuali == 0", plotOutput("pieplot")),
          br(),
          downloadButton("QualitativePieDownload", "Download Graph", class = "btn-primary"),
          br(), br(),
          shinyWidgets::dropdown(
            label = "Customize graph",tags$h3("Customize"),div(
        style = "display: inline-block;vertical-align:top; width: 100%; text-align: center; margin-bottom: 10px;",
        shinyWidgets::actionBttn(
          inputId = "resetPieplot",
          label = "Reset to Initial State",
          style = "bordered",
          color = "warning",
          size = "sm",
          icon = icon("refresh")
        )
      ),
            div(style="display: inline-block;vertical-align:top;
        width: 150px;",selectInput("fontPie", " Font", choices = fuentes)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            textInput("labelfill",
                      label = "Label",
                      value = "Write...")),
        div(
          style="display: inline-block;vertical-align:top; width: 150px;",
          selectInput("paletaspie",
                      "Palletes",
                      choices = paletas)),
        div(style="display: inline-block;vertical-align:top;width: 150px;",
            sliderInput(inputId = "fontpie",
                        label = "Size font" ,
                        min = 1  ,
                        max =50 ,
                        value = 12)),
        div(style="display: inline-block;vertical-align:top; width: 150px;",
            sliderInput(inputId = "alphapie",
                        label = "alpha",
                        min = 0.001 ,
                        max =1 ,
                        value = 0.7)),
        style = "unite",
        icon = icon("fish"),
        status = "primary",
        width = "500px",
        animate = shinyWidgets::animateOptions(
          enter = shinyWidgets::animations$fading_entrances$fadeInLeftBig,
          exit = shinyWidgets::animations$fading_exits$fadeOutRightBig))))